@@ -9,7 +9,7 @@ require Exporter;
 our @ISA = qw(Exporter);
 our @EXPORT_OK = qw( etch paint );
 
-our $VERSION = '1.00';
+our $VERSION = '1.01';
 
 sub readgif {
   my($io, $chrs) = @_;
@@ -160,7 +160,7 @@ embed a trivial perl program in it using the following snippet:
 	      <table width="100%">
 		  <tr>
 		    <td width="30%">
-		      <center><img src="world.gif" alt=""></center>
+		      <center><img src="http://www.cs.auckland.ac.nz/~jas/CPAN/Perl-Visualize/examples/world.gif" alt=""></center>
 		    </td>
 		    <td width="5%">+</td>
 		    <td width="30%">
@@ -171,7 +171,7 @@ embed a trivial perl program in it using the following snippet:
 		    <td width="5%">=</td>
 		    <td>
 		      <center>
-			<a href="helloworld.gif">helloworld.gif</a>
+			<a href="http://www.cs.auckland.ac.nz/~jas/CPAN/Perl-Visualize/examples/helloworld.gif">helloworld.gif</a>
 		      </center>
 		    </td>
 		  </tr>
@@ -179,6 +179,10 @@ embed a trivial perl program in it using the following snippet:
 
 =end html
 
+Original image L<http://www.cs.auckland.ac.nz/~jas/CPAN/Perl-Visualize/examples/world.gif>
+
+Polyglot image L<http://www.cs.auckland.ac.nz/~jas/CPAN/Perl-Visualize/examples/helloworld.gif>
+
 This results in a valid GIF file can be directly executed by the perl
 interpreter simply by calling C<perl helloworld.gif> or viewed in any
 GIF browser.
@@ -209,7 +213,7 @@ AT&T.
 	      <table width="100%">
 		  <tr>
 		    <td width="30%">
-		      <center><img src="fibo.gif" alt=""></center>
+		      <center><img src="http://www.cs.auckland.ac.nz/~jas/CPAN/Perl-Visualize/examples/fibo.gif" alt=""></center>
 		    </td>
 		    <td width="5%">+</td>
 		    <td width="30%">
@@ -228,7 +232,7 @@ fib(10,1,1);
 		    <td width="5%">=</td>
 		    <td>
 		      <center>
-			<a href="v-fibo.gif">v-fibo.gif</a>
+			<a href="http://www.cs.auckland.ac.nz/~jas/CPAN/Perl-Visualize/examples/v-fibo.gif">v-fibo.gif</a>
 		      </center>
 		    </td>
 		  </tr>
@@ -236,6 +240,12 @@ fib(10,1,1);
 
 =end html
 
+Original image L<http://www.cs.auckland.ac.nz/~jas/CPAN/Perl-Visualize/examples/fibo.gif>
+
+Embedded code L<http://www.cs.auckland.ac.nz/~jas/CPAN/Perl-Visualize/examples/fibo.pl>
+
+Polyglot image L<http://www.cs.auckland.ac.nz/~jas/CPAN/Perl-Visualize/examples/v-fibo.gif>
+
 =head2 The Art of Computer Programs
 
 Piet is a programming language in which programs look like abstract
@@ -263,7 +273,7 @@ executable using perl.
 	      <table width="100%">
 		  <tr>
 		    <td width="30%">
-		      <center><img src="piet.gif" alt=""></center>
+		      <center><img src="http://www.cs.auckland.ac.nz/~jas/CPAN/Perl-Visualize/examples/piet.gif" alt=""></center>
 		    </td>
 		    <td width="5%">+</td>
 		    <td width="30%">
@@ -277,7 +287,7 @@ executable using perl.
 		    <td width="5%">=</td>
 		    <td>
 		      <center>
-			<a href="v-piet.gif">v-piet.gif</a>
+			<a href="http://www.cs.auckland.ac.nz/~jas/CPAN/Perl-Visualize/examples/v-piet.gif">v-piet.gif</a>
 		      </center>
 		    </td>
 		  </tr>
@@ -285,6 +295,10 @@ executable using perl.
 
 =end html
 
+Original image L<http://www.cs.auckland.ac.nz/~jas/CPAN/Perl-Visualize/examples/piet.gif>
+
+Polyglot image L<http://www.cs.auckland.ac.nz/~jas/CPAN/Perl-Visualize/examples/v-piet.gif>
+
 Note that the program we embed is very simple.  It simply calls the
 Piet::Interpreter with itself (C<$0>) as the argument.  This example
 is interesting because it actually interprets the same GIF file twice
@@ -434,11 +448,8 @@ Finally, we embed the edited C<$_> in a GIF file.
   m/^__END__(.*)/ms;
   Perl::Visualize::paint ( '99.gif', '99.gif', "\$_=<<'CODE';\n${_}CODE".$1);
 
-=begin html
 
-The resulting program can be found <a href="99.gif">here</a>
-
-=end html
+Polyglot image L<http://www.cs.auckland.ac.nz/~jas/CPAN/Perl-Visualize/examples/99.gif>
 
 =head1 HOW IT ALL WORKS
 
